@@ -5,7 +5,6 @@
 #include <QFile>
 #include <QFileDialog>
 #include <QTextStream>
-#include <QColorDialog>
 #include <QIcon>
 #include <QListWidgetItem>
 #include <QMessageBox>
@@ -24,7 +23,7 @@ class BackgroundDlg : public QDialog {
     Q_DISABLE_COPY(BackgroundDlg)
 public:
     //! Constructor.
-    explicit BackgroundDlg(QWidget *parent = 0);
+    explicit BackgroundDlg(QWidget *parent = 0, const QString &currentRemoteName = 0);
     //! Destructor.
     virtual ~BackgroundDlg();
     //! Variable for background pixmap which is returned to QtIrreco class.
@@ -40,9 +39,6 @@ public:
     //! Method for returning backgrounds name.
     QString returnBackgroundImagePath();
 
-protected:
-    virtual void changeEvent(QEvent *e);
-
 private:
     Ui::BackgroundDlg *m_ui;
     //! Pixmap used for preview label.
@@ -71,6 +67,12 @@ private:
     void process_line(QString line, const int CONF_TYPE);
     //! Method for loading existing themes to listwidget.
     void loadThemes();
+    //! Dir for theme.
+    QDir themeDirs;
+    //! Background image path.
+    QString bgImagePath;
+    //! Remote name which selected when background dialog opened.
+    QString remoteName;
 
 private slots:
     //! Opens filedialog for selecting background image.
@@ -88,13 +90,13 @@ private slots:
     //! Slot which is called when tab is changed.
     void activateTab(const int tabIndex);
     //! Sets backgroundcolor variable.
-    void setBackgroundColor(const QColor bgc);
+    void setBackgroundColor(const QColor &bgc);
     //! Sets RGB values and emits them to LayoutWidget class.
-    void rgbFromColorDlg(const QString red,const QString green,const QString blue);
+    void rgbFromColorDlg(const QString &red,const QString &green,const QString &blue);
 
 signals:
     //! Signals which emits RGB values and background mode
-    void rgbToLw(QString red,QString green,QString blue);
+    void rgbToLw(const QString &red, const QString &green, const QString &blue);
     //! Signal that mode changed.
     void backgroundChanged(int bgMode);
 };
