@@ -48,6 +48,7 @@ void LayoutWidget::openEditDlg()
 
 void LayoutWidget::editButton(QString fileNameUnPressed, QString fileNamePressed, QString confFileName, QString buttonText, QStringList commands, int number, int timeOut)
 {
+     Q_UNUSED(number);
      QPoint position = newButton->pos();
 
      ButtonWidget *pw = new ButtonWidget(this, fileNameUnPressed, fileNamePressed, confFileName, buttonText, commands, timeOut);
@@ -325,7 +326,7 @@ void LayoutWidget::addButton(QString fileNameUnPressed, QString fileNamePressed,
      QStringList themeVersionsUsed;
      if(backgroundMode == backgroundFromTheme) {
         QString bgTheme = bgPath;
-        bgTheme = bgTheme.remove(0,35);
+        bgTheme = bgTheme.remove(0,26);
         int slashIndex = bgTheme.indexOf(QChar('/'));
         bgTheme.remove(slashIndex,bgTheme.count()-slashIndex);
         if(!themesUsed.contains(bgTheme))
@@ -335,8 +336,8 @@ void LayoutWidget::addButton(QString fileNameUnPressed, QString fileNamePressed,
     for( int i=0 ; i<vector->count() ; i++ ) {
         QString themeName;
         QString temp = vector->at(i)->fileNameUnPressed;
-        if(!temp.contains("/home/user/.qtirreco")) {
-            temp = temp.remove(0,35);
+        if(!temp.contains("/opt/qtirreco/defaulttheme")) {
+            temp = temp.remove(0,26);
             int slashIndex = temp.indexOf(QChar('/'));
             temp.remove(slashIndex,temp.count()-slashIndex);
             themeName = temp;
