@@ -8,8 +8,11 @@ QtIrreco::QtIrreco(QWidget *parent)
     this->initMenu();
      //Creates empty remotes.conf file
     QFile file(remotesConf);
-    if (!file.open(QIODevice::ReadWrite | QIODevice::Text))
+    if (!file.open(QIODevice::ReadWrite | QIODevice::Text)) {
+        QMessageBox::warning(this,"Error with remotes file",
+                             "The program was unable to make remotes.conf file",Qt::NoButton,Qt::NoButton);
         return;
+    }
     file.close();
 
     remoteNames = new QStringList();
@@ -52,8 +55,36 @@ QtIrreco::~QtIrreco()
     delete m_ui;
 
 }
+void QtIrreco::changeOldRemoteButtonPaths(QString fileName) // CAN BE DELETED LATER WHEN PROLLY ALL USERS HAVE
+                                                               //   TRIED OLD REMOTES SO THEY ARE FIXED
+{
+    QFile file(remotesPath + fileName);
+    file.open(QIODevice::ReadOnly | QIODevice::Text);
+    QTextStream in(&file);
+    QString data = in.readAll();
+
+    if(data.contains("/home/user/.qtirreco/themes/default",Qt::CaseInsensitive))
+        data.replace("/home/user/.qtirreco/themes/default","/home/opt/qtirreco/defaulttheme");
+
+    if(data.contains("/home/user/MyDocs/qtirreco/.themes",Qt::CaseInsensitive))
+        data.replace("/home/user/MyDocs/qtirreco/.themes","/home/opt/qtirreco/themes");
+
+    file.remove();
+
+    QFile newFile(remotesPath + fileName);
+    newFile.open(QIODevice::WriteOnly | QIODevice::Text);
+    newFile.write(data.toLatin1(),qstrlen(data.toLatin1()));
+
+    newFile.close();
+}
+
 void QtIrreco::setActiveRemote()
 {
+    // If remote has old paths change them to new.
+    changeOldRemoteButtonPaths(activeRemote+".conf");
+    // Can be deleted later.
+
+
      lw->setActiveRemoteName(activeRemote);
      backgroundName.clear();
      QFile file(remotesPath + activeRemote+".conf");
@@ -65,6 +96,10 @@ void QtIrreco::setActiveRemote()
             this->readRemoteFile(line, in.atEnd());
         }
     file.close();
+
+    // THESE LINES CAN BE DELETED LATER! ! !!! ! ! !
+    this->editRemote();
+    this->saveRemote();
 }
 
 void QtIrreco::checkForRemotes()
@@ -418,7 +453,6 @@ void QtIrreco::saveRemote()
             line = line.trimmed();
             line.remove(0,9);
             QString string;
-
             for(int i=0;i<line.length();i++) {
                 if(line.at(i).isSpace() == false)
                     string.append(line.at(i));
@@ -799,9 +833,9 @@ void QtIrreco::addDownloadedRemote(QString remName)
     remConf.chop(5);
     remoteNames->append(remName);
     activeRemote = remConf;
-    //Download Lirc configurations if needed
+    //Downloads Lirc configurations if needed
     checkLircFilesForRemote(remName);
-    //Download themes if needed
+    //Downloads themes if needed
     checkThemesForRemote(remName);
 }
 
@@ -809,8 +843,11 @@ void QtIrreco::checkThemesForRemote(QString remoteFile)
 {
     QString themeTemp;
     QFile file(remotesPath + remoteFile);
-        if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
+    if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
+        QMessageBox::warning(this,"Error with remote file",
+                             "The program was unable to open " + remoteFile,Qt::NoButton,Qt::NoButton);
         return;
+    }
         QTextStream in(&file);
         while (!in.atEnd()) {
             QString line = in.readLine();
@@ -853,6 +890,8 @@ void QtIrreco::checkThemesForRemote(QString remoteFile)
     }
 
     if(themesForRemote.isEmpty()) {
+        this->setEnabled(true);
+        lw->clearScreen();
         lw->setActiveRemoteName(activeRemote);
         this->writeRemoteChanges();
         this->checkForRemotes();
@@ -862,15 +901,19 @@ void QtIrreco::checkThemesForRemote(QString remoteFile)
         m_ui->actionSelectRemote->setEnabled(true);
         m_ui->actionDeleteRemote->setEnabled(true);
         m_ui->actionUploadDb->setEnabled(true);
+
+
+    }
+    else {
+        themeDownloadCount = 0;
+        progress = new QProgressBar(this);
+        progress->setGeometry(650,10,128,64);
+        progress->setRange(0,100);
+        connect(this,SIGNAL(progressState(int)),progress,SLOT(setValue(int)));
+        connect(this,SIGNAL(themeLoaded()),progress,SLOT(deleteLater()));
+        progress->show();
+        this->downloadTheme();
     }
-    themeDownloadCount = 0;
-    progress = new QProgressBar(this);
-    progress->setGeometry(650,10,128,64);
-    progress->setRange(0,100);
-    connect(this,SIGNAL(progressState(int)),progress,SLOT(setValue(int)));
-    connect(this,SIGNAL(themeLoaded()),progress,SLOT(deleteLater()));
-    progress->show();
-    this->downloadTheme();
 }
 void QtIrreco::downloadTheme()
 {
