@@ -50,6 +50,8 @@ private:
     void enableUseMenu();
     //! Method for checking if any remotes have been created.
     void checkForRemotes();
+    //! If remote has old paths change them to new.           LATER CAN BE DELETED WHEN ALL USERS CHANGED TO NEW VERSION
+    void changeOldRemoteButtonPaths(QString fileName);
     //! Few dialog objects.
     RemoteStartupDlg *rsd;
     BackgroundDlg *bg;
