@@ -145,7 +145,7 @@ void RemoteStartupDlg::on_pushButton_clicked()
 
         if(customTheme) {
             // Open theme manager and ask which theme wanted to use in buttons.
-            ThemeManager *themeDlg = new ThemeManager(this);
+            themeDlg = new ThemeManager(this);
             themeDlg->setRemoteStartupProperties();
             connect(themeDlg,SIGNAL(themeChoosed(QString)),this,SLOT(setThemeName(QString)));
             themeDlg->exec();
