@@ -9,11 +9,12 @@ ThemeManager::ThemeManager(QWidget *parent) :
     remoteStartup = false;
     m_ui->commentTextEdit->setProperty("FingerScrollable", true);
 
-    if(this->parent()->objectName() != "remoteStartupDlg") {
-        this->setWindowTitle("Theme manager");
-        m_ui->listWidget->addItem("Device");
-        m_ui->listWidget->addItem("Database");
-    }
+    if(parent)
+        if(this->parent()->objectName() != "remoteStartupDlg") {
+            this->setWindowTitle("Theme manager");
+            m_ui->listWidget->addItem("Device");
+            m_ui->listWidget->addItem("Database");
+        }
 
     m_ui->downloadPushButton->setDisabled(true);
     m_ui->previousPushButton->setDisabled(true);
@@ -1011,7 +1012,7 @@ void ThemeManager::deleteTheme(QString delThemeName)
         file.remove();
     }
     dir.setPath(homePath);
-    QString delCommand("rm -rf /home/user/MyDocs/qtirreco/.themes/" + delThemeName);
+    QString delCommand("rm -rf /home/opt/qtirreco/themes/" + delThemeName);
     system(delCommand.toAscii().data());
 }
 void ThemeManager::deleteTheme()
@@ -1050,7 +1051,7 @@ void ThemeManager::deleteTheme()
         file.remove();
     }
     dir.setPath(homePath);
-    QString delCommand("rm -rf /home/user/MyDocs/qtirreco/.themes/" + themeToDelete);
+    QString delCommand("rm -rf /home/opt/qtirreco/themes/" + themeToDelete);
     system(delCommand.toAscii().data());
     QDir themeDir(themesPath + themeToDelete);
     if(!themeDir.exists())
@@ -1113,7 +1114,7 @@ void ThemeManager::replaceTheme()
         file.remove();
     }
     dir.setPath(homePath);
-    QString delCommand("rm -rf /home/user/MyDocs/qtirreco/.themes/" + themeToDelete);
+    QString delCommand("rm -rf /home/opt/qtirreco/themes/" + themeToDelete);
     system(delCommand.toAscii().data());
 
     QDir themeDir(themesPath + themeToDelete);
