@@ -1,6 +1,5 @@
 #include "uploaddbdlg.h"
 #include "ui_uploaddbdlg.h"
-#include "logindbdlg.h"
 
 UploadDBDlg::UploadDBDlg(QWidget *parent,QString confFile) :
     QDialog(parent),
@@ -35,21 +34,9 @@ UploadDBDlg::~UploadDBDlg()
     delete m_ui;
 }
 
-void UploadDBDlg::changeEvent(QEvent *e)
-{
-    QDialog::changeEvent(e);
-    switch (e->type()) {
-    case QEvent::LanguageChange:
-        m_ui->retranslateUi(this);
-        break;
-    default:
-        break;
-    }
-}
-
 void UploadDBDlg::on_UploadButton_clicked()
 {
-    LoginDbDlg *loginDlg = new LoginDbDlg(this);
+    loginDlg = new LoginDbDlg(this);
     connect(loginDlg,SIGNAL(loginReady(QString,QString)),this,SLOT(uploadRemote(QString,QString)));
     loginDlg->exec();
 }
